<?php

/*
 * We have different include behaviour for the pages based
 * on if the user is logged in.
 *
 * We have two 'modes' for these things:
 *    - logged in
 *    - not logged in
 *
 * If a user is logged in, functions can also be based on
 * specific permissions, but this is taken care of by
 * individual pages (i.e. they must get it right).
 *
 */
function get_page_path($page)
{
  global $logged_in;

  if($logged_in) {
    if(is_file('authenticated/'.$page.'.inc')) {
      // we're logged in, and authenticated page exists... so...
      $page_inc = 'authenticated/'.$page.".inc";
    } else {
      if(is_file('unauthenticated/'.$page.'.inc')) {
	// try the unauthenticated page, as there isn't an auth version
	$page_inc = 'unauthenticated/'.$page.'.inc';
      } else {
	// the file doesn't exist, and we're authenticated
	my_syslog(LOG_WARNING,"Unknown page passed while auth, defaulting to index: $page");
	$page = 'index';
	$page_inc = 'unauthenticated/'.$page.'.inc';
      }
    }
  } else {
    if(is_file('unauthenticated/'.$page.'.inc')) {
    // we're not authenticated, and not logged in, but the page exists.
      $page_inc = 'unauthenticated/'.$page.'.inc';
    } else {
      if(is_file($page.'.inc'))	{
	// The inc file is in the current dir
	$page_inc = $page.'.inc';
      } else {
	// default back to index
	my_syslog(LOG_WARNING,"Unknown page passed while unauth, defaulting to index: $page");
	$page = 'index';
	$page_inc = 'unauthenticated/index.inc';
      }
    }
  }

  return $page_inc;
}

function show_menu($menu)
{
  global $logged_in;
  foreach ($menu as $page) {  
    if(isset($page['category'])) {
      $s = show_menu($page['items']);
      if($s) {
	$str.='<li>';
	if(isset($page['page']))
	  $str.='<a href="?page='.$page['page'].'">';
	$str.=$page['category'];
	if(isset($page['page']))
	  $str.='</a>';
	$str.='<ul>'.$s.'</ul></li>';
      } else if(isset($page['page'])) {
	if(!$page['logged_in'] || ($logged_in && $page['logged_in']))
	  $str.='<li><a href="?page='.$page['page'].'">'.
	    $page['category'].'</a></li>';
      }
    } else if(!isset($page['activity'])
	      || has_permission(get_member_id($_SESSION['user']),
				$page['activity'])
	      ) {
      if(!$page['logged_in'] || ($logged_in && $page['logged_in']))
	$str.='<li><a href="?page='.
	  $page['page'].'">'.
	  $page['title'].'</a></li>';
    }
  }
  
  return $str;
}

?>
